@@ -4,6 +4,7 @@ var cli = require("./3scale-cli");
 var slug = require("slug");
 var Q = require("q");
 var request = Q.denodeify(require("request"));
+var HttpError = require('http-error-constructor');
 
 exports.createService = function(name){
     var url = config.API+"/services.json";
@@ -20,11 +21,21 @@ exports.createService = function(name){
     var response = request(options);
 
     return response.then(function (r) {
-      var res  = r[0].req.res;
-      var body = JSON.parse(res.body);
+     var res  = r[0].req.res;
+     try {
+       var body = JSON.parse(res.body);
+     } catch(e) {
+     }
       if (res.statusCode >= 300) {
-        cli.error({message:"ERROR encountered: " + body.error});
-        throw new Error("Server responded with status code " + res[0].req.res.statusCode,body.error);
+        var err = new HttpError(res.statusCode)
+        var message = "ERROR encountered: "
+        if(body && body.error){ //error message in body
+          message += body.error
+        }else{
+          message += "["+res.statusCode+"] "+err.message
+        }
+        cli.error({message: message});
+        throw new Error("Server responded with status code " + res.statusCode);
       } else {
         config.add("threescale:service_id",body.service.id);
         return body.service;//assuming tapes are strings and not binary data
